@@ -175,7 +175,7 @@ typedef struct getdns_tcp_state {
 typedef struct getdns_network_req
 {
 	/* For storage in upstream->netreq_by_query_id */
-	getdns_rbnode_t node;
+	_getdns_rbnode_t node;
 	/* the async_id from unbound */
 	int unbound_id;
 	/* state var */
@@ -227,7 +227,7 @@ typedef struct getdns_network_req
  */
 typedef struct getdns_dns_req {
 	/* For storage in context->outbound_requests */
-	getdns_rbnode_t node;
+	_getdns_rbnode_t node;
 
 	/* name */
 	uint8_t name[256];
@@ -321,10 +321,10 @@ typedef struct getdns_dns_req {
 extern getdns_dict *dnssec_ok_checking_disabled;
 
 /* dns request utils */
-getdns_dns_req *dns_req_new(getdns_context *context, getdns_eventloop *loop,
+getdns_dns_req *_getdns_dns_req_new(getdns_context *context, getdns_eventloop *loop,
     const char *name, uint16_t request_type, getdns_dict *extensions);
 
-void dns_req_free(getdns_dns_req * req);
+void _getdns_dns_req_free(getdns_dns_req * req);
 
 #endif
 /* types-internal.h */
